ELIB
----

Etcher's personal library for silly utility functions

|OSI|

|license|
|av|
|codacy|
|coverage|
|ccissues|
|ccmain|
|requires|
|bch|
|bp|
|cf|

|graph|

.. |OSI| image:: https://badges.frapsoft.com/os/v3/open-source-200x33.png?v=103
    :target: https://github.com/ellerbrock/open-source-badges/
    :alt: '<3 Open Source'
.. |license| image:: https://img.shields.io/github/license/132nd-etcher/elib.svg
    :target: https://github.com/132nd-etcher/elib/blob/master/LICENSE
    :alt: 'License'
.. |av| image:: https://img.shields.io/appveyor/ci/132nd-etcher/elib/master.svg?label=master
    :target: https://ci.appveyor.com/project/132nd-etcher/elib
    :alt: 'Appveyor build'
.. |codacy| image:: https://img.shields.io/codacy/grade/41cd1e485219427b8ebc56e381550caf.svg
    :target: https://www.codacy.com/app/132nd-etcher/elib
    :alt: 'Codacy grade'
.. |coverage| image:: https://img.shields.io/codacy/coverage/41cd1e485219427b8ebc56e381550caf.svg
    :target: https://www.codacy.com/app/132nd-etcher/elib
    :alt: 'Codacy coverage'
.. |graph| image:: https://graphs.waffle.io/132nd-etcher/elib/throughput.svg
    :target: https://waffle.io/132nd-etcher/elib/metrics/throughput
    :alt: 'Throughput Graph'
.. |requires| image:: https://requires.io/github/132nd-etcher/elib/requirements.svg?branch=master
    :target: https://requires.io/github/132nd-etcher/elib/requirements/?branch=master
    :alt: 'Requires.io'
.. |ccissues| image:: https://img.shields.io/codeclimate/issues/github/132nd-etcher/elib.svg
    :target: https://codeclimate.com/github/132nd-etcher/elib
    :alt: 'CodeClimate issues'
.. |ccmain| image:: https://img.shields.io/codeclimate/maintainability/132nd-etcher/elib.svg
    :target: https://codeclimate.com/github/132nd-etcher/elib
    :alt: 'CodeClimate maintainability'
.. |bch| image:: https://bettercodehub.com/edge/badge/132nd-etcher/elib?branch=master
    :target: https://bettercodehub.com/results/132nd-etcher/elib
    :alt: 'BetterCodeHub'
.. |bp| image:: https://bestpractices.coreinfrastructure.org/projects/1547/badge
    :target: https://bestpractices.coreinfrastructure.org/projects/1547
    :alt: 'OSI Best Practices'
.. |cf| image:: https://www.codefactor.io/repository/github/132nd-etcher/elib/badge
    :target: https://www.codefactor.io/repository/github/132nd-etcher/elib
    :alt: 'CodeFactor'
